@@ -24,27 +24,35 @@
 #include "cpl_memory.h"
 #include "cpl_mpfit.h"
 
+
+/*
+ * The function declarations of this module have been modified by adding
+ * the prefix '_cpl_' to static functions, and 'cpl_' to public functions
+ * to protect the namespace.
+ */
+
 /* Forward declarations of functions in this module */
-static int mp_fdjac2(mp_func funct,
+
+static int _cpl_mp_fdjac2(mp_func funct,
 	      int m, int n, int *ifree, int npar, double *x, double *fvec,
 	      double *fjac, int ldfjac, double epsfcn,
 	      double *wa, void *priv, int *nfev,
 	      double *step, double *dstep, int *dside,
 	      int *qulimited, double *ulimit,
 	      int *ddebug, double *ddrtol, double *ddatol);
-static void mp_qrfac(int m, int n, double *a, int lda, 
+static void _cpl_mp_qrfac(int m, int n, double *a, int lda,
 	      int pivot, int *ipvt, int lipvt,
 	      double *rdiag, double *acnorm, double *wa);
-static void mp_qrsolv(int n, double *r, int ldr, int *ipvt, double *diag,
+static void _cpl_mp_qrsolv(int n, double *r, int ldr, int *ipvt, double *diag,
 	       double *qtb, double *x, double *sdiag, double *wa);
-static void mp_lmpar(int n, double *r, int ldr, int *ipvt, int *ifree, double *diag,
+static void _cpl_mp_lmpar(int n, double *r, int ldr, int *ipvt, int *ifree, double *diag,
 	      double *qtb, double delta, double *par, double *x,
 	      double *sdiag, double *wa1, double *wa2);
-static double mp_enorm(int n, double *x);
-static double mp_dmax1(double a, double b);
-static double mp_dmin1(double a, double b);
-static int mp_min0(int a, int b);
-static int mp_covar(int n, double *r, int ldr, int *ipvt, double tol, double *wa);
+static double _cpl_mp_enorm(int n, double *x);
+static double _cpl_mp_dmax1(double a, double b);
+static double _cpl_mp_dmin1(double a, double b);
+static int _cpl_mp_min0(int a, int b);
+static int _cpl_mp_covar(int n, double *r, int ldr, int *ipvt, double tol, double *wa);
 
 /* Macro to call user function */
 #define mp_call(funct, m, n, x, fvec, dvec, priv) (*(funct))(m,n,x,fvec,dvec,priv)
@@ -273,9 +281,8 @@ static int mp_covar(int n, double *r, int ldr, int *ipvt, double tol, double *wa
 * ********** */
 
 
-int mpfit(mp_func funct, int m, int npar,
-	  double *xall, mp_par *pars, mp_config *config, void *private_data, 
-	  mp_result *result)
+int cpl_mpfit(mp_func funct, int m, int npar, double *xall, mp_par *pars,
+              mp_config *config, void *private_data, mp_result *result)
 {
   mp_config conf;
   int i, j, info, iflag, nfree, npegged, iter;
@@ -455,7 +462,7 @@ int mpfit(mp_func funct, int m, int npar,
     goto CLEANUP;
   }
 
-  fnorm = mp_enorm(m, fvec);
+  fnorm = _cpl_mp_enorm(m, fvec);
   orignorm = fnorm*fnorm;
 
   /* Make a new copy */
@@ -485,10 +492,10 @@ int mpfit(mp_func funct, int m, int npar,
   /* XXX call iterproc */
 
   /* Calculate the jacobian matrix */
-  iflag = mp_fdjac2(funct, m, nfree, ifree, npar, xnew, fvec, fjac, ldfjac,
-		    conf.epsfcn, wa4, private_data, &nfev,
-		    step, dstep, mpside, qulim, ulim,
-		    ddebug, ddrtol, ddatol);
+  iflag = _cpl_mp_fdjac2(funct, m, nfree, ifree, npar, xnew, fvec, fjac,
+                         ldfjac, conf.epsfcn, wa4, private_data, &nfev,
+                         step, dstep, mpside, qulim, ulim, ddebug, ddrtol,
+                         ddatol);
   if (iflag < 0) {
     goto CLEANUP;
   }
@@ -520,7 +527,7 @@ int mpfit(mp_func funct, int m, int npar,
   } 
 
   /* Compute the QR factorization of the jacobian */
-  mp_qrfac(m,nfree,fjac,ldfjac,1,ipvt,nfree,wa1,wa2,wa3);
+  _cpl_mp_qrfac(m,nfree,fjac,ldfjac,1,ipvt,nfree,wa1,wa2,wa3);
 
   /*
    *	 on the first iteration and if mode is 1, scale according
@@ -544,7 +551,7 @@ int mpfit(mp_func funct, int m, int npar,
       wa3[j] = diag[ifree[j]] * x[j];
     }
     
-    xnorm = mp_enorm(nfree, wa3);
+    xnorm = _cpl_mp_enorm(nfree, wa3);
     delta = conf.stepfactor*xnorm;
     if (delta == zero) delta = conf.stepfactor;
   }
@@ -618,7 +625,7 @@ int mpfit(mp_func funct, int m, int npar,
 	  sum += fjac[ij]*(qtf[i]/fnorm);
 	  ij += 1; /* fjac[i+m*j] */
 	}
-	gnorm = mp_dmax1(gnorm,fabs(sum/wa2[l]));
+	gnorm = _cpl_mp_dmax1(gnorm,fabs(sum/wa2[l]));
       }
       jj += m;
     }
@@ -636,7 +643,7 @@ int mpfit(mp_func funct, int m, int npar,
    */
   if (conf.douserscale == 0) {
     for (j=0; j<nfree; j++ ) {
-      diag[ifree[j]] = mp_dmax1(diag[ifree[j]],wa2[j]);
+      diag[ifree[j]] = _cpl_mp_dmax1(diag[ifree[j]],wa2[j]);
     }
   }
 
@@ -647,7 +654,8 @@ int mpfit(mp_func funct, int m, int npar,
   /*
    *	    determine the levenberg-marquardt parameter.
    */
-  mp_lmpar(nfree,fjac,ldfjac,ipvt,ifree,diag,qtf,delta,&par,wa1,wa2,wa3,wa4);
+  _cpl_mp_lmpar(nfree,fjac,ldfjac,ipvt,ifree,diag,qtf,delta,&par,
+                wa1,wa2,wa3,wa4);
   /*
    *	    store the direction p and x + p. calculate the norm of p.
    */
@@ -676,10 +684,10 @@ int mpfit(mp_func funct, int m, int npar,
       if (upegged && (wa1[j] > 0)) wa1[j] = 0;
 
       if (dwa1 && qllim[j] && ((x[j] + wa1[j]) < llim[j])) {
-	alpha = mp_dmin1(alpha, (llim[j]-x[j])/wa1[j]);
+	alpha = _cpl_mp_dmin1(alpha, (llim[j]-x[j])/wa1[j]);
       }
       if (dwa1 && qulim[j] && ((x[j] + wa1[j]) > ulim[j])) {
-	alpha = mp_dmin1(alpha, (ulim[j]-x[j])/wa1[j]);
+	alpha = _cpl_mp_dmin1(alpha, (ulim[j]-x[j])/wa1[j]);
       }
     }
     
@@ -713,13 +721,13 @@ int mpfit(mp_func funct, int m, int npar,
     wa3[j] = diag[ifree[j]]*wa1[j];
   }
 
-  pnorm = mp_enorm(nfree,wa3);
+  pnorm = _cpl_mp_enorm(nfree,wa3);
   
   /*
    *	    on the first iteration, adjust the initial step bound.
    */
   if (iter == 1) {
-    delta = mp_dmin1(delta,pnorm);
+    delta = _cpl_mp_dmin1(delta,pnorm);
   }
 
   /*
@@ -733,7 +741,7 @@ int mpfit(mp_func funct, int m, int npar,
   nfev += 1;
   if (iflag < 0) goto L300;
 
-  fnorm1 = mp_enorm(m,wa4);
+  fnorm1 = _cpl_mp_enorm(m,wa4);
 
   /*
    *	    compute the scaled actual reduction.
@@ -765,7 +773,7 @@ int mpfit(mp_func funct, int m, int npar,
    * taken
    */
 
-  temp1 = mp_enorm(nfree,wa3)*alpha/fnorm;
+  temp1 = _cpl_mp_enorm(nfree,wa3)*alpha/fnorm;
   temp2 = (sqrt(alpha*par)*pnorm)/fnorm;
   prered = temp1*temp1 + (temp2*temp2)/p5;
   dirder = -(temp1*temp1 + temp2*temp2);
@@ -793,7 +801,7 @@ int mpfit(mp_func funct, int m, int npar,
 	|| (temp < p1) ) {
       temp = p1;
     }
-    delta = temp*mp_dmin1(delta,pnorm/p1);
+    delta = temp*_cpl_mp_dmin1(delta,pnorm/p1);
     par = par/temp;
   } else {
     if ((par == zero) || (ratio >= p75) ) {
@@ -817,7 +825,7 @@ int mpfit(mp_func funct, int m, int npar,
     for (i=0; i<m; i++ ) {
       fvec[i] = wa4[i];
     }
-    xnorm = mp_enorm(nfree,wa2);
+    xnorm = _cpl_mp_enorm(nfree,wa2);
     fnorm = fnorm1;
     iter += 1;
   }
@@ -902,7 +910,7 @@ int mpfit(mp_func funct, int m, int npar,
 
   /* Compute and return the covariance matrix and/or parameter errors */
   if (result && (result->covar || result->xerror)) {
-    mp_covar(nfree, fjac, ldfjac, ipvt, conf.covtol, wa2);
+    _cpl_mp_covar(nfree, fjac, ldfjac, ipvt, conf.covtol, wa2);
     
     if (result->covar) {
       /* Zero the destination covariance array */
@@ -928,7 +936,7 @@ int mpfit(mp_func funct, int m, int npar,
 
   if (result) {
     strcpy(result->version, MPFIT_VERSION);
-    result->bestnorm = mp_dmax1(fnorm,fnorm1);
+    result->bestnorm = _cpl_mp_dmax1(fnorm,fnorm1);
     result->bestnorm *= result->bestnorm;
     result->orignorm = orignorm;
     result->status   = info;
@@ -979,13 +987,13 @@ int mpfit(mp_func funct, int m, int npar,
 /************************fdjac2.c*************************/
 
 static 
-int mp_fdjac2(mp_func funct,
-	      int m, int n, int *ifree, int npar, double *x, double *fvec,
-	      double *fjac, int ldfjac, double epsfcn,
-	      double *wa, void *priv, int *nfev,
-	      double *step, double *dstep, int *dside,
-	      int *qulimited, double *ulimit,
-	      int *ddebug, double *ddrtol, double *ddatol)
+int _cpl_mp_fdjac2(mp_func funct,
+                   int m, int n, int *ifree, int npar, double *x, double *fvec,
+                   double *fjac, int ldfjac, double epsfcn,
+                   double *wa, void *priv, int *nfev,
+                   double *step, double *dstep, int *dside,
+                   int *qulimited, double *ulimit,
+                   int *ddebug, double *ddrtol, double *ddatol)
 {
 /*
 *     **********
@@ -1072,7 +1080,7 @@ int mp_fdjac2(mp_func funct,
   int has_analytical_deriv = 0, has_numerical_deriv = 0;
   int has_debug_deriv = 0;
   
-  temp = mp_dmax1(epsfcn,MP_MACHEP0);
+  temp = _cpl_mp_dmax1(epsfcn,MP_MACHEP0);
   eps = sqrt(temp);
   ij = 0;
   ldfjac = 0; /* Prevents compiler warning */
@@ -1222,9 +1230,9 @@ int mp_fdjac2(mp_func funct,
 /************************qrfac.c*************************/
  
 static 
-void mp_qrfac(int m, int n, double *a, int lda, 
-	      int pivot, int *ipvt, int lipvt,
-	      double *rdiag, double *acnorm, double *wa)
+void _cpl_mp_qrfac(int m, int n, double *a, int lda,
+                   int pivot, int *ipvt, int lipvt,
+                   double *rdiag, double *acnorm, double *wa)
 {
 /*
 *     **********
@@ -1317,7 +1325,7 @@ void mp_qrfac(int m, int n, double *a, int lda,
    */
   ij = 0;
   for (j=0; j<n; j++) {
-    acnorm[j] = mp_enorm(m,&a[ij]);
+    acnorm[j] = _cpl_mp_enorm(m,&a[ij]);
     rdiag[j] = acnorm[j];
     wa[j] = rdiag[j];
     if (pivot != 0)
@@ -1327,7 +1335,7 @@ void mp_qrfac(int m, int n, double *a, int lda,
   /*
    *     reduce a to r with householder transformations.
    */
-  minmn = mp_min0(m,n);
+  minmn = _cpl_mp_min0(m,n);
   for (j=0; j<minmn; j++) {
     if (pivot == 0)
       goto L40;
@@ -1365,7 +1373,7 @@ void mp_qrfac(int m, int n, double *a, int lda,
      *	 j-th column of a to a multiple of the j-th unit vector.
      */
     jj = j + m*j;
-    ajnorm = mp_enorm(m-j,&a[jj]);
+    ajnorm = _cpl_mp_enorm(m-j,&a[jj]);
     if (ajnorm == zero)
       goto L100;
     if (a[jj] < zero)
@@ -1407,12 +1415,12 @@ void mp_qrfac(int m, int n, double *a, int lda,
 	    if ((pivot != 0) && (rdiag[k] != zero))
 	      {
 		temp = a[j+m*k]/rdiag[k];
-		temp = mp_dmax1( zero, one-temp*temp );
+		temp = _cpl_mp_dmax1( zero, one-temp*temp );
 		rdiag[k] *= sqrt(temp);
 		temp = rdiag[k]/wa[k];
 		if ((p05*temp*temp) <= MP_MACHEP0)
 		  {
-		    rdiag[k] = mp_enorm(m-j-1,&a[jp1+m*k]);
+		    rdiag[k] = _cpl_mp_enorm(m-j-1,&a[jp1+m*k]);
 		    wa[k] = rdiag[k];
 		  }
 	      }
@@ -1430,7 +1438,7 @@ void mp_qrfac(int m, int n, double *a, int lda,
 /************************qrsolv.c*************************/
 
 static 
-void mp_qrsolv(int n, double *r, int ldr, int *ipvt, double *diag,
+void _cpl_mp_qrsolv(int n, double *r, int ldr, int *ipvt, double *diag,
 	       double *qtb, double *x, double *sdiag, double *wa)
 {
 /*
@@ -1656,9 +1664,9 @@ void mp_qrsolv(int n, double *r, int ldr, int *ipvt, double *diag,
 /************************lmpar.c*************************/
 
 static 
-void mp_lmpar(int n, double *r, int ldr, int *ipvt, int *ifree, double *diag,
-	      double *qtb, double delta, double *par, double *x,
-	      double *sdiag, double *wa1, double *wa2) 
+void _cpl_mp_lmpar(int n, double *r, int ldr, int *ipvt, int *ifree, double *diag,
+                   double *qtb, double delta, double *par, double *x,
+                   double *sdiag, double *wa1, double *wa2)
 {
   /*     **********
    *
@@ -1809,7 +1817,7 @@ void mp_lmpar(int n, double *r, int ldr, int *ipvt, int *ifree, double *diag,
   iter = 0;
   for (j=0; j<n; j++)
     wa2[j] = diag[ifree[j]]*x[j];
-  dxnorm = mp_enorm(n,wa2);
+  dxnorm = _cpl_mp_enorm(n,wa2);
   fp = dxnorm - delta;
   if (fp <= p1*delta) {
     goto L220;
@@ -1843,7 +1851,7 @@ void mp_lmpar(int n, double *r, int ldr, int *ipvt, int *ifree, double *diag,
 	wa1[j] = (wa1[j] - sum)/r[j+ldr*j];
 	jj += ldr; /* [i+ldr*j] */
       }
-    temp = mp_enorm(n,wa1);
+    temp = _cpl_mp_enorm(n,wa1);
     parl = ((fp/delta)/temp)/temp;
   }
   /*
@@ -1862,16 +1870,16 @@ void mp_lmpar(int n, double *r, int ldr, int *ipvt, int *ifree, double *diag,
     wa1[j] = sum/diag[ifree[l]];
     jj += ldr; /* [i+ldr*j] */
   }
-  gnorm = mp_enorm(n,wa1);
+  gnorm = _cpl_mp_enorm(n,wa1);
   paru = gnorm/delta;
   if (paru == zero)
-    paru = MP_DWARF/mp_dmin1(delta,p1);
+    paru = MP_DWARF/_cpl_mp_dmin1(delta,p1);
   /*
    *     if the input par lies outside of the interval (parl,paru),
    *     set par to the closer endpoint.
    */
-  *par = mp_dmax1( *par,parl);
-  *par = mp_dmin1( *par,paru);
+  *par = _cpl_mp_dmax1( *par,parl);
+  *par = _cpl_mp_dmin1( *par,paru);
   if (*par == zero)
     *par = gnorm/dxnorm;
 
@@ -1884,14 +1892,14 @@ void mp_lmpar(int n, double *r, int ldr, int *ipvt, int *ifree, double *diag,
    *	 evaluate the function at the current value of par.
    */
   if (*par == zero)
-    *par = mp_dmax1(MP_DWARF,p001*paru);
+    *par = _cpl_mp_dmax1(MP_DWARF,p001*paru);
   temp = sqrt( *par );
   for (j=0; j<n; j++)
     wa1[j] = temp*diag[ifree[j]];
-  mp_qrsolv(n,r,ldr,ipvt,wa1,qtb,x,sdiag,wa2);
+  _cpl_mp_qrsolv(n,r,ldr,ipvt,wa1,qtb,x,sdiag,wa2);
   for (j=0; j<n; j++)
     wa2[j] = diag[ifree[j]]*x[j];
-  dxnorm = mp_enorm(n,wa2);
+  dxnorm = _cpl_mp_enorm(n,wa2);
   temp = fp;
   fp = dxnorm - delta;
   /*
@@ -1926,19 +1934,19 @@ void mp_lmpar(int n, double *r, int ldr, int *ipvt, int *ifree, double *diag,
       }
     jj += ldr; /* ldr*j */
   }
-  temp = mp_enorm(n,wa1);
+  temp = _cpl_mp_enorm(n,wa1);
   parc = ((fp/delta)/temp)/temp;
   /*
    *	 depending on the sign of the function, update parl or paru.
    */
   if (fp > zero)
-    parl = mp_dmax1(parl, *par);
+    parl = _cpl_mp_dmax1(parl, *par);
   if (fp < zero)
-    paru = mp_dmin1(paru, *par);
+    paru = _cpl_mp_dmin1(paru, *par);
   /*
    *	 compute an improved estimate for par.
    */
-  *par = mp_dmax1(parl, *par + parc);
+  *par = _cpl_mp_dmax1(parl, *par + parc);
   /*
    *	 end of an iteration.
    */
@@ -1959,7 +1967,7 @@ void mp_lmpar(int n, double *r, int ldr, int *ipvt, int *ifree, double *diag,
 /************************enorm.c*************************/
  
 static 
-double mp_enorm(int n, double *x) 
+double _cpl_mp_enorm(int n, double *x)
 {
   /*
    *     **********
@@ -2091,7 +2099,7 @@ double mp_enorm(int n, double *x)
 /************************lmmisc.c*************************/
 
 static 
-double mp_dmax1(double a, double b) 
+double _cpl_mp_dmax1(double a, double b)
 {
   if (a >= b)
     return(a);
@@ -2100,7 +2108,7 @@ double mp_dmax1(double a, double b)
 }
 
 static 
-double mp_dmin1(double a, double b)
+double _cpl_mp_dmin1(double a, double b)
 {
   if (a <= b)
     return(a);
@@ -2109,7 +2117,7 @@ double mp_dmin1(double a, double b)
 }
 
 static 
-int mp_min0(int a, int b)
+int _cpl_mp_min0(int a, int b)
 {
   if (a <= b)
     return(a);
@@ -2187,7 +2195,7 @@ c     **********
 */
 
 static 
-int mp_covar(int n, double *r, int ldr, int *ipvt, double tol, double *wa)
+int _cpl_mp_covar(int n, double *r, int ldr, int *ipvt, double tol, double *wa)
 {
   int i, ii, j, jj, k, l;
   int kk, kj, ji, j0, k0, jj0;
