@@ -40,6 +40,7 @@
 #endif
 
 #include <string.h>
+#include <assert.h>
 
 /*---------------------------------------------------------------------------*/
 /**
@@ -326,16 +327,31 @@ cpl_error_code cpl_fft_imagelist(cpl_imagelist       * self,
 #if defined CPL_FFTWF_INSTALLED || defined CPL_FFTW_INSTALLED
 /*----------------------------------------------------------------------------*/
 /**
-  @brief  Return CPL_TRUE on proper alignment (4 bits or matching align mask)
+  @internal
+  @brief  Return aligned (4 bits or matching align mask) pointer
   @param  self  Pointer to return, if aligned
   @param  other Aligned pointer, returned if self is not aligned
   @param  align Pattern
   @return Aligned pointer
+  @note It is not checked whether other is in fact aligned
 
  */
 /*----------------------------------------------------------------------------*/
 static void * cpl_fft_aligned(void * self, void * other, size_t align)
 {
+#ifdef HAVE_FFTW_ALIGNMENT_OF
+    /* FIXME: Available from FFTW 3.3.4 */
+    int iself, iother;
+#ifdef _OPENMP
+#pragma omp critical(cpl_fft_fftw)
+#endif
+    {
+        iself  = fftw_alignment_of((double*)self);
+        iother = fftw_alignment_of((double*)other);
+    }
+
+    return iself == iother ? self : other;
+#else
     const size_t myself = (const size_t)self;
     size_t lsb = 1;
 
@@ -348,5 +364,6 @@ static void * cpl_fft_aligned(void * self, void * other, size_t align)
 
     /* Iff self has a 1 where lsb has a 1, then self is not aligned */
     return (myself & lsb) ? other : self;
+#endif
 }
 #endif
